@@ -10,9 +10,9 @@ Interacts with OWL Tools API
 * gets_object_properties
 * gets_ontology_class_dbxrefs
 * gets_ontology_class_synonyms
+* gets_ontology_definitions
 * merges_ontologies
 * ontology_file_formatter
-* adds_annotation_assertions
 
 Interacts with Knowledge Graphs
 * adds_edges_to_graph
@@ -43,7 +43,6 @@ import json
 import networkx as nx  # type: ignore
 import os
 import os.path
-import random
 
 from collections import Counter  # type: ignore
 from more_itertools import unique_everseen  # type: ignore
@@ -81,6 +80,25 @@ def gets_ontology_classes(graph: Graph) -> Set:
     return class_list
 
 
+def gets_ontology_definitions(graph: Graph) -> Dict:
+    """Queries a knowledge graph and returns a list of all object definitions (obo:IAO_0000115) in the graph.
+
+    Args:
+        graph: An rdflib Graph object.
+
+    Returns:
+        obj_defs: A dictionary where keys are object URiRefs and values are Literal object definitions. For example:
+                    {rdflib.term.URIRef('http://purl.obolibrary.org/obo/OBI_0001648'):
+                     rdflib.term.Literal('A B cell epitope qualitative binding to antibody assay that uses an antibody
+                     cross-blocking assay.', datatype=rdflib.term.URIRef('http://www.w3.org/2001/XMLSchema#string')),
+                     ...}
+    """
+
+    obj_defs = {x[0]: x[2] for x in graph.triples((None, obo.IAO_0000115, None))}
+
+    return obj_defs
+
+
 def gets_deprecated_ontology_classes(graph: Graph) -> Set:
     """Queries a knowledge graph and returns a list of all deprecated owl:Class objects in the graph.
 
@@ -130,14 +148,17 @@ def gets_ontology_class_synonyms(graph: Graph) -> Tuple:
                     {'susceptibility to herpesvirus': 'hasExactSynonym', 'full upper lip': 'hasExactSynonym'}
     """
 
+    synonyms: Dict = dict()
     class_list = [x for x in graph if 'synonym' in str(x[1]).lower() and isinstance(x[0], URIRef)]
-    synonyms = {str(x[2]).lower(): str(x[0]) for x in class_list}
+    for x in class_list:
+        if str(x[2]).lower() in synonyms.keys(): synonyms[str(x[2]).lower()].append(str(x[0]))
+        else: synonyms[str(x[2]).lower()] = [str(x[0])]
     synonym_type = {str(x[2]).lower(): str(x[1]).split('#')[-1] for x in class_list}
 
     return synonyms, synonym_type
 
 
-def gets_ontology_class_dbxrefs(graph: Graph):
+def gets_ontology_class_dbxrefs(graph: Graph) -> Tuple:
     """Queries a knowledge graph and returns a dictionary containing all owl:Class objects and their database
     cross references (dbxref). Function also includes exact matches. A tuple of dictionaries: (1) contains dbxref and
     exact matches (URIs and labels); and (2) contains dbxref/exactmatch uris and a string indicating the type (i.e.
@@ -153,10 +174,19 @@ def gets_ontology_class_dbxrefs(graph: Graph):
         dbxref_type: A dict where keys are dbxref/exact uris; values are str indicating if the uri is dbxref or exact.
     """
 
+    dbx_uris: Dict = dict()
     dbx = [x for x in graph if 'hasdbxref' in str(x[1]).lower() if isinstance(x[0], URIRef)]
-    dbx_uris, dbx_type = {str(x[2]).lower(): str(x[0]) for x in dbx}, {str(x[2]).lower(): 'DbXref' for x in dbx}
+    for x in dbx:
+        if str(x[2]).lower() in dbx_uris.keys(): dbx_uris[str(x[2]).lower()].append(str(x[0]))
+        else: dbx_uris[str(x[2]).lower()] = [str(x[0])]
+    dbx_type = {str(x[2]).lower(): 'DbXref' for x in dbx}
+
+    ex_uris: Dict = dict()
     ex = [x for x in graph if 'exactmatch' in str(x[1]).lower() if isinstance([0], URIRef)]
-    ex_uris, ex_type = {str(x[2]).lower(): str(x[0]) for x in ex}, {str(x[2]).lower(): 'ExactMatch' for x in ex}
+    for x in ex:
+        if str(x[2]).lower() in ex_uris.keys(): ex_uris[str(x[2]).lower()].append(str(x[0]))
+        else: ex_uris[str(x[2]).lower()] = [str(x[0])]
+    ex_type = {str(x[2]).lower(): 'ExactMatch' for x in ex}
 
     return {**dbx_uris, **ex_uris}, {**dbx_type, **ex_type}
 
@@ -361,7 +391,8 @@ def gets_entity_ancestors(graph: Graph, uris: List[Union[URIRef, str]], rel: Uni
     if len(ancs) == 0 or len(set(ancs).difference(set(cls_lst))) == 0:
         return list(unique_everseen([str(x) for x in cls_lst]))
     else:
-        uris = [x for x in ancs if x not in cls_lst]; cls_lst.insert(0, [x for x in uris][0])
+        uris = [x for x in ancs if x not in cls_lst]
+        for i in uris: cls_lst.insert(0, i)
         return gets_entity_ancestors(graph, uris, prop, cls_lst)
 
 
